import { PublishCommand, SNSClient } from '@aws-sdk/client-sns';
export const sendErrorToSlack = async (snsTopicArn, context, error) => {
    try {
        const region = context.invokedFunctionArn.split(':')[3];
        const logGroup = context.logGroupName.replaceAll('/', '%2F');
        const logStream = context.logStreamName.replaceAll('/', '%2F');
        const lambdaLink = `<https://${region}.console.aws.amazon.com/lambda/home?region=${region}#/functions/${context.functionName}?code&tab=code|${context.functionName}>`;
        const logsLink = `<https://${region}.console.aws.amazon.com/cloudwatch/home?region=${region}#logsV2:log-groups/log-group/${logGroup}/log-events/${logStream}?filterPattern="${context.awsRequestId}"|Logs>`;
        const errorMessage = isNativeError(error)
            ? `\`${error.message}\`\n\`\`\`${error.stack}\`\`\``
            : `\`\`\`${error}\`\`\``;
        await new SNSClient({ region }).send(new PublishCommand({
            TopicArn: snsTopicArn,
            Message: JSON.stringify({
                version: '1.0',
                source: 'custom',
                content: {
                    description: `${lambdaLink} (${logsLink})\n${errorMessage}`,
                },
            }),
        }));
    }
    catch (err) {
        console.error(`Unable to send error to Slack (SNS Topic ARN: ${snsTopicArn})\n${err}`);
    }
};
function isNativeError(error) {
    if (!error)
        return false;
    if (typeof error !== 'object')
        return false;
    return 'message' in error && 'stack' in error;
}
//# sourceMappingURL=sendErrorToSlack.js.map